/* Driver template for the LEMON parser generator.
** The author disclaims copyright to this source code.
*/
/* First off, code is included that follows the "include" declaration
** in the input grammar file. */
#include <stdio.h>
#line 24 "src/CFCParseHeader.y"

#include <stdio.h>
#include <string.h>
#include <assert.h>
#include <stdlib.h>
#include "CFC.h"
#include "CFCLexHeader.h"
#ifndef true
  #define true 1
  #define false 0
#endif

static CFCClass*
S_start_class(CFCParser *state, CFCDocuComment *docucomment, char *exposure,
              char *modifiers, char *class_name, char *class_nickname,
              char *inheritance) {
    CFCFileSpec *file_spec = CFCParser_get_file_spec(state);
    int is_final = false;
    int is_inert = false;
    if (modifiers) {
        /* TODO: Decide how to handle abstract classes. */
        if (strstr(modifiers, "inline")) {
            CFCUtil_die("Illegal class modifiers: '%s'", modifiers);
        }
        is_final = !!strstr(modifiers, "final");
        is_inert = !!strstr(modifiers, "inert");
    }
    CFCParser_set_class_name(state, class_name);
    CFCParser_set_class_nickname(state, class_nickname);
    CFCClass *klass = CFCClass_create(CFCParser_get_parcel(state), exposure,
                                      class_name, class_nickname, NULL,
                                      docucomment, file_spec, inheritance,
                                      is_final, is_inert);
    CFCBase_decref((CFCBase*)docucomment);
    return klass;
}

static CFCVariable*
S_new_var(CFCParser *state, char *exposure, char *modifiers, CFCType *type,
          char *name) {
    int inert = false;
    if (modifiers) {
        if (strcmp(modifiers, "inert") != 0) {
            CFCUtil_die("Illegal variable modifiers: '%s'", modifiers);
        }
        inert = true;
    }

    CFCParcel  *parcel         = CFCParser_get_parcel(state);
    const char *class_name     = NULL;
    const char *class_nickname = NULL;
    if (exposure && strcmp(exposure, "local") != 0) {
        class_name     = CFCParser_get_class_name(state);
        class_nickname = CFCParser_get_class_nickname(state);
    }
    CFCVariable *var = CFCVariable_new(parcel, exposure, class_name,
                                       class_nickname, name, type, inert);

    /* Consume tokens. */
    CFCBase_decref((CFCBase*)type);

    return var;
}

static CFCBase*
S_new_sub(CFCParser *state, CFCDocuComment *docucomment, 
          char *exposure, char *modifiers, CFCType *type, char *name,
          CFCParamList *param_list) {
    CFCParcel  *parcel         = CFCParser_get_parcel(state);
    const char *class_name     = CFCParser_get_class_name(state);
    const char *class_nickname = CFCParser_get_class_nickname(state);

    /* Find modifiers by scanning the list. */
    int is_abstract = false;
    int is_final    = false;
    int is_inline   = false;
    int is_inert    = false;
    if (modifiers) {
        is_abstract = !!strstr(modifiers, "abstract");
        is_final    = !!strstr(modifiers, "final");
        is_inline   = !!strstr(modifiers, "inline");
        is_inert    = !!strstr(modifiers, "inert");
    }

    /* If "inert", it's a function, otherwise it's a method. */
    CFCBase *sub;
    if (is_inert) {
        if (is_abstract) {
            CFCUtil_die("Inert functions must not be abstract");
        }
        if (is_final) {
            CFCUtil_die("Inert functions must not be final");
        }
        sub = (CFCBase*)CFCFunction_new(parcel, exposure, class_name,
                                         class_nickname, name, type,
                                         param_list, docucomment, is_inline);
    }
    else {
        if (is_inline) {
            CFCUtil_die("Methods must not be inline");
        }
        sub = (CFCBase*)CFCMethod_new(parcel, exposure, class_name,
                                       class_nickname, name, type, param_list,
                                       docucomment, is_final, is_abstract);
    }

    /* Consume tokens. */
    CFCBase_decref((CFCBase*)docucomment);
    CFCBase_decref((CFCBase*)type);
    CFCBase_decref((CFCBase*)param_list);

    return sub;
}

static CFCType*
S_new_type(CFCParser *state, int flags, char *type_name,
           char *asterisk_postfix, char *array_postfix) {
    (void)state; /* unused */
    CFCType *type = NULL;
    size_t type_name_len = strlen(type_name);
    int indirection = asterisk_postfix ? (int)strlen(asterisk_postfix) : 0;

    /* Apply "nullable" to outermost pointer, but "const", etc to innermost
     * type. This is an ugly kludge and the Clownfish header language needs to
     * be fixed, either to support C's terrible pointer type syntax, or to do
     * something better. */
    int composite_flags = 0;
    if (indirection) {
        composite_flags = flags & CFCTYPE_NULLABLE;
        flags &= ~CFCTYPE_NULLABLE;
    }

    if (!strcmp(type_name, "int8_t")
        || !strcmp(type_name, "int16_t")
        || !strcmp(type_name, "int32_t")
        || !strcmp(type_name, "int64_t")
        || !strcmp(type_name, "uint8_t")
        || !strcmp(type_name, "uint16_t")
        || !strcmp(type_name, "uint32_t")
        || !strcmp(type_name, "uint64_t")
        || !strcmp(type_name, "char")
        || !strcmp(type_name, "short")
        || !strcmp(type_name, "int")
        || !strcmp(type_name, "long")
        || !strcmp(type_name, "size_t")
        || !strcmp(type_name, "bool")
       ) {
        type = CFCType_new_integer(flags, type_name);
    }
    else if (!strcmp(type_name, "float")
             || !strcmp(type_name, "double")
            ) {
        type = CFCType_new_float(flags, type_name);
    }
    else if (!strcmp(type_name, "void")) {
        type = CFCType_new_void(!!(flags & CFCTYPE_CONST));
    }
    else if (!strcmp(type_name, "va_list")) {
        type = CFCType_new_va_list();
    }
    else if (type_name_len > 2
             && !strcmp(type_name + type_name_len - 2, "_t")
            ) {
        type = CFCType_new_arbitrary(CFCParser_get_parcel(state), type_name);
    }
    else if (indirection > 0) {
        /* The only remaining possibility is an object type, and we can let
         * the constructor perform the complex validation of the type name. */
        indirection--;
        if (indirection == 0) {
            flags |= composite_flags;
            composite_flags = 0;
        }
        type = CFCType_new_object(flags, CFCParser_get_parcel(state), type_name, 1);
    }
    else {
        CFCUtil_die("Invalid type specification at/near '%s'", type_name);
    }

    if (indirection) {
        CFCType *composite = CFCType_new_composite(composite_flags, type,
                                                   indirection, NULL);
        CFCBase_decref((CFCBase*)type);
        type = composite;
    }
    else if (array_postfix) {
        CFCType *composite = CFCType_new_composite(composite_flags, type,
                                                   0, array_postfix);
        CFCBase_decref((CFCBase*)type);
        type = composite;
    }

    return type;
}

#line 204 "src/CFCParseHeader.c"
/* Next is all token values, in a form suitable for use by makeheaders.
** This section will be null unless lemon is run with the -m switch.
*/
/* 
** These constants (all generated automatically by the parser generator)
** specify the various kinds of tokens (terminals) that the parser
** understands. 
**
** Each symbol here is a terminal symbol in the grammar.
*/
/* Make sure the INTERFACE macro is defined.
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/* The next thing included is series of defines which control
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 terminals
**                       and nonterminals.  "int" is used otherwise.
**    YYNOCODE           is a number of type YYCODETYPE which corresponds
**                       to no legal terminal or nonterminal number.  This
**                       number is used to fill in empty slots of the hash 
**                       table.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       have fall-back values which should be used if the
**                       original value of the token will not parse.
**    YYACTIONTYPE       is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 rules and
**                       states combined.  "int" is used otherwise.
**    CFCParseHeaderTOKENTYPE     is the data type used for minor tokens given 
**                       directly to the parser from the tokenizer.
**    YYMINORTYPE        is the data type used for all minor tokens.
**                       This is typically a union of many types, one of
**                       which is CFCParseHeaderTOKENTYPE.  The entry in the union
**                       for base tokens is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    CFCParseHeaderARG_SDECL     A static variable declaration for the %extra_argument
**    CFCParseHeaderARG_PDECL     A parameter declaration for the %extra_argument
**    CFCParseHeaderARG_STORE     Code to store %extra_argument into yypParser
**    CFCParseHeaderARG_FETCH     Code to extract %extra_argument from yypParser
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
*/
#define YYCODETYPE unsigned char
#define YYNOCODE 75
#define YYACTIONTYPE unsigned short int
#define CFCParseHeaderTOKENTYPE char*
typedef union {
  int yyinit;
  CFCParseHeaderTOKENTYPE yy0;
  int yy8;
  CFCParcel* yy14;
  CFCType* yy41;
  CFCFile* yy51;
  CFCVariable* yy57;
  CFCDocuComment* yy73;
  CFCBase* yy82;
  CFCParamList* yy96;
  CFCCBlock* yy117;
  CFCClass* yy141;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define CFCParseHeaderARG_SDECL  CFCParser *state ;
#define CFCParseHeaderARG_PDECL , CFCParser *state 
#define CFCParseHeaderARG_FETCH  CFCParser *state  = yypParser->state 
#define CFCParseHeaderARG_STORE yypParser->state  = state 
#define YYNSTATE 191
#define YYNRULE 117
#define YY_NO_ACTION      (YYNSTATE+YYNRULE+2)
#define YY_ACCEPT_ACTION  (YYNSTATE+YYNRULE+1)
#define YY_ERROR_ACTION   (YYNSTATE+YYNRULE)

/* The yyzerominor constant is used to initialize instances of
** YYMINORTYPE objects to zero. */
static const YYMINORTYPE yyzerominor = { 0 };

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N < YYNSTATE                  Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   YYNSTATE <= N < YYNSTATE+YYNRULE   Reduce by rule N-YYNSTATE.
**
**   N == YYNSTATE+YYNRULE              A syntax error has occurred.
**
**   N == YYNSTATE+YYNRULE+1            The parser accepts its input.
**
**   N == YYNSTATE+YYNRULE+2            No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as
**
**      yy_action[ yy_shift_ofst[S] + X ]
**
** If the index value yy_shift_ofst[S]+X is out of range or if the value
** yy_lookahead[yy_shift_ofst[S]+X] is not equal to X or if yy_shift_ofst[S]
** is equal to YY_SHIFT_USE_DFLT, it means that the action is not in the table
** and that yy_default[S] should be used instead.  
**
** The formula above is for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
*/
#define YY_ACTTAB_COUNT (1169)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */    56,   55,  231,  302,   57,   89,  123,  122,  121,  120,
 /*    10 */   119,   95,  115,  114,  113,  112,  101,  100,   99,   98,
 /*    20 */   265,  265,  265,  265,  265,  192,  265,  265,  265,  265,
 /*    30 */     9,  131,  184,  184,   77,  182,   92,  309,    2,   42,
 /*    40 */   171,  167,  155,    1,  169,  168,   54,  186,  187,  150,
 /*    50 */     3,  170,  110,   22,  111,    5,   10,  242,  132,  189,
 /*    60 */    21,  242,   20,   96,  242,  242,  242,  242,  242,  242,
 /*    70 */   242,  242,  242,  242,  242,  242,  242,  242,  271,  117,
 /*    80 */   271,  271,  271,  271,  271,  303,  271,  271,  271,  271,
 /*    90 */   271,  271,  271,  271,  242,  245,  193,  291,  291,  245,
 /*   100 */   291,  102,  245,  245,  245,  245,  245,  245,  245,  245,
 /*   110 */   245,  245,  245,  245,  245,  245,  272,  303,  272,  272,
 /*   120 */   272,  272,  272,  223,  272,  272,  272,  272,  272,  272,
 /*   130 */   272,  272,  245,  251,  184,  295,  295,  251,   34,  139,
 /*   140 */   251,  251,  251,  251,  251,  251,  251,  251,  251,  251,
 /*   150 */   251,  251,  251,  251,  273,   77,  273,  273,  273,  273,
 /*   160 */   273,  191,  273,  273,  273,  273,  273,  273,  273,  273,
 /*   170 */   251,  252,  116,  297,  297,  252,   33,   88,  252,  252,
 /*   180 */   252,  252,  252,  252,  252,  252,  252,  252,  252,  252,
 /*   190 */   252,  252,  274,   87,  274,  274,  274,  274,  274,  227,
 /*   200 */   274,  274,  274,  274,  274,  274,  274,  274,  252,  250,
 /*   210 */   207,  134,   40,  250,  128,   86,  250,  250,  250,  250,
 /*   220 */   250,  250,  250,  250,  250,  250,  250,  250,  250,  250,
 /*   230 */   276,   77,  276,  276,  276,  276,  276,  225,  276,  276,
 /*   240 */   276,  276,  276,  276,  276,  276,  250,  249,  215,  127,
 /*   250 */    39,  249,  128,   85,  249,  249,  249,  249,  249,  249,
 /*   260 */   249,  249,  249,  249,  249,  249,  249,  249,  275,   77,
 /*   270 */   275,  275,  275,  275,  275,  229,  275,  275,  275,  275,
 /*   280 */   275,  275,  275,  275,  249,  243,  211,  151,   18,  243,
 /*   290 */   283,  283,  243,  243,  243,  243,  243,  243,  243,  243,
 /*   300 */   243,  243,  243,  243,  243,  243,  264,   77,  264,  264,
 /*   310 */   264,  264,  264,  224,  264,  264,  264,  264,  264,  264,
 /*   320 */   264,  264,  243,  246,  284,  284,  219,  246,  285,  285,
 /*   330 */   246,  246,  246,  246,  246,  246,  246,  246,  246,  246,
 /*   340 */   246,  246,  246,  246,   78,   77,  123,  122,  121,  120,
 /*   350 */   119,  228,  115,  114,  113,  112,  101,  100,   99,   98,
 /*   360 */   246,  244,  286,  286,  209,  244,  287,  287,  244,  244,
 /*   370 */   244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
 /*   380 */   244,  244,   71,   77,  123,  122,  121,  120,  119,  226,
 /*   390 */   115,  114,  113,  112,  101,  100,   99,   98,  244,  247,
 /*   400 */   288,  288,  217,  247,  289,  289,  247,  247,  247,  247,
 /*   410 */   247,  247,  247,  247,  247,  247,  247,  247,  247,  247,
 /*   420 */    60,   77,  123,  122,  121,  120,  119,  230,  115,  114,
 /*   430 */   113,  112,  101,  100,   99,   98,  247,  248,  296,  296,
 /*   440 */   195,  248,  298,  298,  248,  248,  248,  248,  248,  248,
 /*   450 */   248,  248,  248,  248,  248,  248,  248,  248,   58,   77,
 /*   460 */   123,  122,  121,  120,  119,  213,  115,  114,  113,  112,
 /*   470 */   101,  100,   99,   98,  248,  105,  137,  307,  307,  240,
 /*   480 */   306,  306,  240,  240,  240,  240,  240,  240,  240,  240,
 /*   490 */   240,  240,  240,  240,  240,  240,   74,   83,  123,  122,
 /*   500 */   121,  120,  119,  221,  115,  114,  113,  112,  101,  100,
 /*   510 */    99,   98,  240,   90,  104,  136,  196,  241,   53,  183,
 /*   520 */   241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
 /*   530 */   241,  241,  241,  241,   59,  197,  123,  122,  121,  120,
 /*   540 */   119,    9,  115,  114,  113,  112,  101,  100,   99,   98,
 /*   550 */   241,  301,  292,   52,  179,  292,  301,  198,  301,  301,
 /*   560 */   301,  301,  301,  301,  301,  301,  301,  301,  301,  301,
 /*   570 */   301,  301,  239,   51,  176,  239,  239,  239,  239,  239,
 /*   580 */   239,  239,  239,  239,  239,  239,  239,  239,  239,  123,
 /*   590 */   122,  121,  120,  119,   95,  115,  114,  113,  112,  101,
 /*   600 */   100,   99,   98,   50,  173,  239,  194,  293,   46,  162,
 /*   610 */   293,   68,  199,  123,  122,  121,  120,  119,   95,  115,
 /*   620 */   114,  113,  112,  101,  100,   99,   98,  106,   45,  160,
 /*   630 */   123,  122,  121,  120,  119,   95,  115,  114,  113,  112,
 /*   640 */   101,  100,   99,   98,  123,  122,  121,  120,  119,   81,
 /*   650 */   115,  114,  113,  112,  101,  100,   99,   98,   24,   37,
 /*   660 */    92,  123,  122,  121,  120,  119,   96,  115,  114,  113,
 /*   670 */   112,  123,  122,  121,  120,  119,  259,  115,  114,  113,
 /*   680 */   112,   44,  158,   94,   93,   65,   80,  259,  188,    4,
 /*   690 */   294,  110,   22,  294,    8,   17,  153,  259,  259,   21,
 /*   700 */    84,   38,   96,  266,  266,  266,  266,  266,   96,  266,
 /*   710 */   266,  266,  266,  267,  267,  267,  267,  267,  208,  267,
 /*   720 */   267,  267,  267,  268,  268,  268,  268,  268,    9,  268,
 /*   730 */   268,  268,  268,  270,  270,  270,  270,  270,  126,  270,
 /*   740 */   270,  270,  270,  269,  269,  269,  269,  269,  202,  269,
 /*   750 */   269,  269,  269,  202,  116,   82,   79,  124,  118,  152,
 /*   760 */   202,  290,  110,   22,  290,  202,  202,  202,  202,  216,
 /*   770 */    21,   43,  156,  123,  122,  121,  120,  119,  212,  115,
 /*   780 */   114,  113,  112,    9,  220,  202,  203,  210,  202,  218,
 /*   790 */   214,  203,  290,  290,  290,   36,  290,  109,  203,  108,
 /*   800 */   155,    1,   96,  203,  203,  203,  203,  235,   19,  107,
 /*   810 */   222,   79,  125,   23,   35,  200,   91,  110,   22,   75,
 /*   820 */    57,   96,    9,  203,  204,   21,  203,   95,   32,  204,
 /*   830 */   140,  181,  101,  100,   99,   98,  204,  184,   31,   77,
 /*   840 */   182,  204,  204,  204,  204,  147,  149,  148,  146,  145,
 /*   850 */   144,  143,   92,   72,  178,   42,   30,  175,   69,   67,
 /*   860 */   291,  204,  206,   90,  204,  110,   22,  206,    7,   15,
 /*   870 */    29,   66,  172,   21,  206,  260,   96,   49,   67,  206,
 /*   880 */   206,  206,  206,  164,  110,   22,  260,    6,   12,   48,
 /*   890 */    28,    9,   21,  279,   68,   96,  260,  260,   47,  206,
 /*   900 */   304,   95,  206,   61,  279,  304,  101,  100,   99,   98,
 /*   910 */    27,  299,  304,  254,  299,  279,   62,  304,  304,  304,
 /*   920 */   304,  103,  110,   22,  254,   26,   16,   25,   55,  135,
 /*   930 */    21,   41,  185,   96,  133,   73,  180,  304,  305,  190,
 /*   940 */   304,  110,   22,  305,  299,   14,  299,  299,  177,   21,
 /*   950 */   305,  278,   96,  174,   73,  305,  305,  305,  305,  166,
 /*   960 */   110,   22,  278,   62,   13,  138,  165,  163,   21,  110,
 /*   970 */    22,   96,  278,   11,  161,  305,  201,   21,  305,  159,
 /*   980 */    96,  201,  300,  157,  142,  300,   78,  130,  201,   97,
 /*   990 */   310,   71,  141,  201,  201,  201,  201,   60,  101,  100,
 /*  1000 */    99,   98,  310,  101,  100,   99,   98,  310,  310,  101,
 /*  1010 */   100,   99,   98,  201,  205,  300,  201,  300,  300,  205,
 /*  1020 */   310,  310,  310,   58,  310,  310,  205,  310,  310,   74,
 /*  1030 */   310,  205,  205,  205,  205,  101,  100,   99,   98,  310,
 /*  1040 */   310,  101,  100,   99,   98,  310,  310,   59,  310,   64,
 /*  1050 */   310,  205,  310,  310,  205,  110,   22,  261,   63,  101,
 /*  1060 */   100,   99,   98,   21,  110,   22,   97,  310,  261,  310,
 /*  1070 */    70,  262,   21,  233,  310,   97,  110,   22,  261,  261,
 /*  1080 */   263,  310,  262,   76,   21,  237,  310,   97,  310,  110,
 /*  1090 */    22,  263,  262,  262,  232,  310,  310,   21,  236,  253,
 /*  1100 */    97,  263,  263,  184,  234,   77,  182,  310,  238,  310,
 /*  1110 */   253,  256,  310,  310,  310,  184,  310,   77,  182,  310,
 /*  1120 */   129,  154,  256,  310,  184,  310,   77,  182,  184,  310,
 /*  1130 */    77,  182,  129,  154,  184,  280,   77,  182,  184,  282,
 /*  1140 */    77,  182,  277,  281,  255,  258,  280,  257,  310,  310,
 /*  1150 */   282,  310,  310,  277,  281,  255,  258,  280,  257,  310,
 /*  1160 */   310,  282,  310,  277,  310,  281,  154,  154,  133,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */     1,    2,    6,    6,    5,    3,    7,    8,    9,   10,
 /*    10 */    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
 /*    20 */     7,    8,    9,   10,   11,    0,   13,   14,   15,   16,
 /*    30 */    31,   23,   36,   36,   38,   39,   37,   44,   45,   40,
 /*    40 */    47,   48,   49,   50,   51,   52,   53,   54,   55,   32,
 /*    50 */    57,   58,   59,   60,   59,   62,   63,    0,   23,   24,
 /*    60 */    67,    4,   67,   70,    7,    8,    9,   10,   11,   12,
 /*    70 */    13,   14,   15,   16,   17,   18,   19,   20,    5,   11,
 /*    80 */     7,    8,    9,   10,   11,    6,   13,   14,   15,   16,
 /*    90 */    17,   18,   19,   20,   37,    0,    0,   32,   33,    4,
 /*   100 */    35,    3,    7,    8,    9,   10,   11,   12,   13,   14,
 /*   110 */    15,   16,   17,   18,   19,   20,    5,   38,    7,    8,
 /*   120 */     9,   10,   11,    6,   13,   14,   15,   16,   17,   18,
 /*   130 */    19,   20,   37,    0,   36,   32,   33,    4,   35,   11,
 /*   140 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   150 */    17,   18,   19,   20,    5,   38,    7,    8,    9,   10,
 /*   160 */    11,    0,   13,   14,   15,   16,   17,   18,   19,   20,
 /*   170 */    37,    0,   11,   32,   33,    4,   35,    3,    7,    8,
 /*   180 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   190 */    19,   20,    5,    3,    7,    8,    9,   10,   11,    6,
 /*   200 */    13,   14,   15,   16,   17,   18,   19,   20,   37,    0,
 /*   210 */     6,   68,   69,    4,   71,    3,    7,    8,    9,   10,
 /*   220 */    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
 /*   230 */     5,   38,    7,    8,    9,   10,   11,    6,   13,   14,
 /*   240 */    15,   16,   17,   18,   19,   20,   37,    0,    6,   68,
 /*   250 */    69,    4,   71,    3,    7,    8,    9,   10,   11,   12,
 /*   260 */    13,   14,   15,   16,   17,   18,   19,   20,    5,   38,
 /*   270 */     7,    8,    9,   10,   11,    6,   13,   14,   15,   16,
 /*   280 */    17,   18,   19,   20,   37,    0,    6,   32,   33,    4,
 /*   290 */    32,   33,    7,    8,    9,   10,   11,   12,   13,   14,
 /*   300 */    15,   16,   17,   18,   19,   20,    5,   38,    7,    8,
 /*   310 */     9,   10,   11,    6,   13,   14,   15,   16,   17,   18,
 /*   320 */    19,   20,   37,    0,   32,   33,    6,    4,   32,   33,
 /*   330 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   340 */    17,   18,   19,   20,    5,   38,    7,    8,    9,   10,
 /*   350 */    11,    6,   13,   14,   15,   16,   17,   18,   19,   20,
 /*   360 */    37,    0,   32,   33,    6,    4,   32,   33,    7,    8,
 /*   370 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   380 */    19,   20,    5,   38,    7,    8,    9,   10,   11,    6,
 /*   390 */    13,   14,   15,   16,   17,   18,   19,   20,   37,    0,
 /*   400 */    32,   33,    6,    4,   32,   33,    7,    8,    9,   10,
 /*   410 */    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
 /*   420 */     5,   38,    7,    8,    9,   10,   11,    6,   13,   14,
 /*   430 */    15,   16,   17,   18,   19,   20,   37,    0,   32,   33,
 /*   440 */     0,    4,   32,   33,    7,    8,    9,   10,   11,   12,
 /*   450 */    13,   14,   15,   16,   17,   18,   19,   20,    5,   38,
 /*   460 */     7,    8,    9,   10,   11,    6,   13,   14,   15,   16,
 /*   470 */    17,   18,   19,   20,   37,   41,   42,   41,   42,    4,
 /*   480 */    41,   42,    7,    8,    9,   10,   11,   12,   13,   14,
 /*   490 */    15,   16,   17,   18,   19,   20,    5,    3,    7,    8,
 /*   500 */     9,   10,   11,    6,   13,   14,   15,   16,   17,   18,
 /*   510 */    19,   20,   37,    3,   41,   42,    0,    4,   64,   65,
 /*   520 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   530 */    17,   18,   19,   20,    5,    0,    7,    8,    9,   10,
 /*   540 */    11,   31,   13,   14,   15,   16,   17,   18,   19,   20,
 /*   550 */    37,    0,    0,   64,   65,    3,    5,    0,    7,    8,
 /*   560 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   570 */    19,   20,    4,   64,   65,    7,    8,    9,   10,   11,
 /*   580 */    12,   13,   14,   15,   16,   17,   18,   19,   20,    7,
 /*   590 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*   600 */    18,   19,   20,   64,   65,   37,    0,    0,   64,   65,
 /*   610 */     3,    5,    0,    7,    8,    9,   10,   11,   12,   13,
 /*   620 */    14,   15,   16,   17,   18,   19,   20,    4,   64,   65,
 /*   630 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   640 */    17,   18,   19,   20,    7,    8,    9,   10,   11,    3,
 /*   650 */    13,   14,   15,   16,   17,   18,   19,   20,   62,   63,
 /*   660 */    37,    7,    8,    9,   10,   11,   70,   13,   14,   15,
 /*   670 */    16,    7,    8,    9,   10,   11,    0,   13,   14,   15,
 /*   680 */    16,   64,   65,   51,   52,   53,    3,   11,   34,   57,
 /*   690 */     0,   59,   60,    3,   62,   63,   32,   21,   22,   67,
 /*   700 */     3,   63,   70,    7,    8,    9,   10,   11,   70,   13,
 /*   710 */    14,   15,   16,    7,    8,    9,   10,   11,    6,   13,
 /*   720 */    14,   15,   16,    7,    8,    9,   10,   11,   31,   13,
 /*   730 */    14,   15,   16,    7,    8,    9,   10,   11,   66,   13,
 /*   740 */    14,   15,   16,    7,    8,    9,   10,   11,    0,   13,
 /*   750 */    14,   15,   16,    5,   11,    3,   53,   54,   11,   56,
 /*   760 */    12,    0,   59,   60,    3,   17,   18,   19,   20,    6,
 /*   770 */    67,   64,   65,    7,    8,    9,   10,   11,    6,   13,
 /*   780 */    14,   15,   16,   31,    6,   37,    0,    6,   40,    6,
 /*   790 */     6,    5,   31,   32,   33,   63,   35,   46,   12,   48,
 /*   800 */    49,   50,   70,   17,   18,   19,   20,    6,   57,   58,
 /*   810 */     6,   53,   54,   62,   63,    0,    6,   59,   60,   66,
 /*   820 */     5,   70,   31,   37,    0,   67,   40,   12,   61,    5,
 /*   830 */    61,   55,   17,   18,   19,   20,   12,   36,   61,   38,
 /*   840 */    39,   17,   18,   19,   20,   24,   25,   26,   27,   28,
 /*   850 */    29,   30,   37,   66,   55,   40,   61,   55,   66,   53,
 /*   860 */     0,   37,    0,    3,   40,   59,   60,    5,   62,   63,
 /*   870 */    61,   66,   55,   67,   12,    0,   70,   66,   53,   17,
 /*   880 */    18,   19,   20,   55,   59,   60,   11,   62,   63,   66,
 /*   890 */    61,   31,   67,    0,    5,   70,   21,   22,   66,   37,
 /*   900 */     0,   12,   40,   66,   11,    5,   17,   18,   19,   20,
 /*   910 */    61,    3,   12,    0,    6,   22,   53,   17,   18,   19,
 /*   920 */    20,   47,   59,   60,   11,   61,   63,   61,    2,   61,
 /*   930 */    67,   66,   65,   70,   21,   53,   65,   37,    0,   55,
 /*   940 */    40,   59,   60,    5,   36,   63,   38,   39,   65,   67,
 /*   950 */    12,    0,   70,   65,   53,   17,   18,   19,   20,   55,
 /*   960 */    59,   60,   11,   53,   63,   73,   55,   65,   67,   59,
 /*   970 */    60,   70,   21,   63,   65,   37,    0,   67,   40,   65,
 /*   980 */    70,    5,    3,   65,   72,    6,    5,   71,   12,   70,
 /*   990 */    74,    5,   72,   17,   18,   19,   20,    5,   17,   18,
 /*  1000 */    19,   20,   74,   17,   18,   19,   20,   74,   74,   17,
 /*  1010 */    18,   19,   20,   37,    0,   36,   40,   38,   39,    5,
 /*  1020 */    74,   74,   74,    5,   74,   74,   12,   74,   74,    5,
 /*  1030 */    74,   17,   18,   19,   20,   17,   18,   19,   20,   74,
 /*  1040 */    74,   17,   18,   19,   20,   74,   74,    5,   74,   53,
 /*  1050 */    74,   37,   74,   74,   40,   59,   60,    0,   53,   17,
 /*  1060 */    18,   19,   20,   67,   59,   60,   70,   74,   11,   74,
 /*  1070 */    53,    0,   67,    6,   74,   70,   59,   60,   21,   22,
 /*  1080 */     0,   74,   11,   53,   67,    6,   74,   70,   74,   59,
 /*  1090 */    60,   11,   21,   22,    6,   74,   74,   67,    6,    0,
 /*  1100 */    70,   21,   22,   36,    6,   38,   39,   74,    6,   74,
 /*  1110 */    11,    0,   74,   74,   74,   36,   74,   38,   39,   74,
 /*  1120 */    21,   22,   11,   74,   36,   74,   38,   39,   36,   74,
 /*  1130 */    38,   39,   21,   22,   36,    0,   38,   39,   36,    0,
 /*  1140 */    38,   39,    0,    0,    0,    0,   11,    0,   74,   74,
 /*  1150 */    11,   74,   74,   11,   11,   11,   11,   22,   11,   74,
 /*  1160 */    74,   22,   74,   21,   74,   22,   22,   22,   21,
};
#define YY_SHIFT_USE_DFLT (-5)
#define YY_SHIFT_COUNT (190)
#define YY_SHIFT_MIN   (-4)
#define YY_SHIFT_MAX   (1147)
static const short yy_shift_ofst[] = {
 /*     0 */    -1,  623,  815,  606,  582,  529,  491,  637,  637,  664,
 /*    10 */   453,  415,  377,  339,  637,  637,  637,  637,  654,  889,
 /*    20 */  1111, 1099,  766, 1042, 1024, 1102, 1098, 1092, 1088, 1079,
 /*    30 */  1067,  801,   -4,  821,  821, 1018,  992,  986,  981, 1145,
 /*    40 */  1144,  860,  473,  421,  383,  345,  307,  752,  697,  510,
 /*    50 */   269,  231,  193,  117,  161,  747,  926,  747,  747,  747,
 /*    60 */   747,  791,  743,  743,  743,  743,  791,  743,  747,  791,
 /*    70 */   743,  747,  791,  743,  747,  791,  743,  747,  747,  743,
 /*    80 */   437,  399,  361,  323,  285,  247,  209,  171,  133,   95,
 /*    90 */    57,  568,  551,  513,  475,  301,  263,  225,  187,  149,
 /*   100 */   111,   73, 1014,  976,  938,  900,  862,  824,  786,  748,
 /*   110 */   736,  726,  716,  706,  696,   13,  761,  979,  908, 1080,
 /*   120 */  1071, 1057,  875,  676,  141,  103,   65, 1147, 1143, 1142,
 /*   130 */  1139, 1135,  893,  951,  913,   98,  439,  436,  434,   79,
 /*   140 */    -3,  410,  406,  372,  368,  334,  330,  296,  292,  258,
 /*   150 */   690,  607,  255,  552,   35,  810,  804,  784,  783,  781,
 /*   160 */   778,  772,  763,  712,  683,  646,  494,  612,  557,  535,
 /*   170 */   516,  440,  250,  497,  459,  212,  396,  358,  190,  320,
 /*   180 */   280,  174,  128,  242,   68,  204,   96,   25,   17,    8,
 /*   190 */     2,
};
#define YY_REDUCE_USE_DFLT (-8)
#define YY_REDUCE_COUNT (79)
#define YY_REDUCE_MIN   (-7)
#define YY_REDUCE_MAX   (1030)
static const short yy_reduce_ofst[] = {
 /*     0 */    -7,  632,  751,  825,  806,  910,  901,  882,  863,  703,
 /*    10 */   996, 1005, 1017, 1030, 1030, 1017, 1005,  996,  758,  596,
 /*    20 */   181,  143,   -5,  732,  638,  707,  617,  564,  544,  539,
 /*    30 */   509,  489,  454,  920,  912,  919,  919,  919,  919,  916,
 /*    40 */   916,  884,  892,  918,  914,  909,  902,  911,  904,  884,
 /*    50 */   888,  883,  871,  867,  865,  868,  874,  866,  864,  849,
 /*    60 */   829,  828,  837,  832,  823,  811,  817,  805,  809,  802,
 /*    70 */   792,  795,  799,  787,  777,  776,  753,  769,  767,  672,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    10 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    20 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    30 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    40 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    50 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    60 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    70 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    80 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*    90 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   100 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   110 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   120 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   130 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   140 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   150 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   160 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   170 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   180 */   308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
 /*   190 */   308,
};

/* The next table maps tokens into fallback tokens.  If a construct
** like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  int yyidx;                    /* Index of top element in stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyidxMax;                 /* Maximum value of yyidx */
#endif
  int yyerrcnt;                 /* Shifts left before out of the error */
  CFCParseHeaderARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void CFCParseHeaderTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "FILE_START",    "PARCEL",        "SEMICOLON",   
  "RIGHT_CURLY_BRACE",  "CLASS",         "LEFT_CURLY_BRACE",  "VOID",        
  "VA_LIST",       "INTEGER_TYPE_NAME",  "FLOAT_TYPE_NAME",  "IDENTIFIER",  
  "PUBLIC",        "CONST",         "NULLABLE",      "INCREMENTED", 
  "DECREMENTED",   "INERT",         "INLINE",        "ABSTRACT",    
  "FINAL",         "ASTERISK",      "LEFT_SQUARE_BRACKET",  "RIGHT_SQUARE_BRACKET",
  "INTEGER_LITERAL",  "HEX_LITERAL",   "FLOAT_LITERAL",  "STRING_LITERAL",
  "TRUE",          "FALSE",         "NULL",          "LEFT_PAREN",  
  "RIGHT_PAREN",   "COMMA",         "ELLIPSIS",      "EQUALS",      
  "SCOPE_OP",      "DOCUCOMMENT",   "INHERITS",      "NICKNAME",    
  "CBLOCK_START",  "CBLOCK_CLOSE",  "BLOB",          "error",       
  "result",        "file",          "major_block",   "parcel_definition",
  "class_declaration",  "class_head",    "class_defs",    "var_declaration_statement",
  "subroutine_declaration_statement",  "type",          "param_variable",  "param_list",  
  "param_list_elems",  "docucomment",   "cblock",        "type_qualifier",
  "type_qualifier_list",  "qualified_id",  "exposure_specifier",  "declaration_modifier_list",
  "nickname",      "class_inheritance",  "declarator",    "type_name",   
  "asterisk_postfix",  "array_postfix",  "declaration_modifier",  "array_postfix_elem",
  "scalar_constant",  "blob",        
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "result ::= type",
 /*   1 */ "result ::= param_list",
 /*   2 */ "result ::= param_variable",
 /*   3 */ "result ::= docucomment",
 /*   4 */ "result ::= parcel_definition",
 /*   5 */ "result ::= cblock",
 /*   6 */ "result ::= var_declaration_statement",
 /*   7 */ "result ::= subroutine_declaration_statement",
 /*   8 */ "result ::= class_declaration",
 /*   9 */ "result ::= file",
 /*  10 */ "file ::= FILE_START parcel_definition",
 /*  11 */ "file ::= file major_block",
 /*  12 */ "major_block ::= class_declaration",
 /*  13 */ "major_block ::= cblock",
 /*  14 */ "parcel_definition ::= PARCEL qualified_id SEMICOLON",
 /*  15 */ "class_declaration ::= class_defs RIGHT_CURLY_BRACE",
 /*  16 */ "class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id nickname class_inheritance",
 /*  17 */ "class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id nickname class_inheritance",
 /*  18 */ "class_head ::= docucomment declaration_modifier_list CLASS qualified_id nickname class_inheritance",
 /*  19 */ "class_head ::= declaration_modifier_list CLASS qualified_id nickname class_inheritance",
 /*  20 */ "class_head ::= docucomment exposure_specifier CLASS qualified_id nickname class_inheritance",
 /*  21 */ "class_head ::= exposure_specifier CLASS qualified_id nickname class_inheritance",
 /*  22 */ "class_head ::= docucomment CLASS qualified_id nickname class_inheritance",
 /*  23 */ "class_head ::= CLASS qualified_id nickname class_inheritance",
 /*  24 */ "class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id class_inheritance",
 /*  25 */ "class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id class_inheritance",
 /*  26 */ "class_head ::= docucomment declaration_modifier_list CLASS qualified_id class_inheritance",
 /*  27 */ "class_head ::= declaration_modifier_list CLASS qualified_id class_inheritance",
 /*  28 */ "class_head ::= docucomment exposure_specifier CLASS qualified_id class_inheritance",
 /*  29 */ "class_head ::= exposure_specifier CLASS qualified_id class_inheritance",
 /*  30 */ "class_head ::= docucomment CLASS qualified_id class_inheritance",
 /*  31 */ "class_head ::= CLASS qualified_id class_inheritance",
 /*  32 */ "class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id nickname",
 /*  33 */ "class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id nickname",
 /*  34 */ "class_head ::= docucomment declaration_modifier_list CLASS qualified_id nickname",
 /*  35 */ "class_head ::= declaration_modifier_list CLASS qualified_id nickname",
 /*  36 */ "class_head ::= docucomment exposure_specifier CLASS qualified_id nickname",
 /*  37 */ "class_head ::= exposure_specifier CLASS qualified_id nickname",
 /*  38 */ "class_head ::= docucomment CLASS qualified_id nickname",
 /*  39 */ "class_head ::= CLASS qualified_id nickname",
 /*  40 */ "class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id",
 /*  41 */ "class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id",
 /*  42 */ "class_head ::= docucomment declaration_modifier_list CLASS qualified_id",
 /*  43 */ "class_head ::= declaration_modifier_list CLASS qualified_id",
 /*  44 */ "class_head ::= docucomment exposure_specifier CLASS qualified_id",
 /*  45 */ "class_head ::= exposure_specifier CLASS qualified_id",
 /*  46 */ "class_head ::= docucomment CLASS qualified_id",
 /*  47 */ "class_head ::= CLASS qualified_id",
 /*  48 */ "class_defs ::= class_head LEFT_CURLY_BRACE",
 /*  49 */ "class_defs ::= class_defs var_declaration_statement",
 /*  50 */ "class_defs ::= class_defs subroutine_declaration_statement",
 /*  51 */ "var_declaration_statement ::= type declarator SEMICOLON",
 /*  52 */ "var_declaration_statement ::= declaration_modifier_list type declarator SEMICOLON",
 /*  53 */ "var_declaration_statement ::= exposure_specifier declaration_modifier_list type declarator SEMICOLON",
 /*  54 */ "subroutine_declaration_statement ::= type declarator param_list SEMICOLON",
 /*  55 */ "subroutine_declaration_statement ::= declaration_modifier_list type declarator param_list SEMICOLON",
 /*  56 */ "subroutine_declaration_statement ::= exposure_specifier declaration_modifier_list type declarator param_list SEMICOLON",
 /*  57 */ "subroutine_declaration_statement ::= exposure_specifier type declarator param_list SEMICOLON",
 /*  58 */ "subroutine_declaration_statement ::= docucomment type declarator param_list SEMICOLON",
 /*  59 */ "subroutine_declaration_statement ::= docucomment declaration_modifier_list type declarator param_list SEMICOLON",
 /*  60 */ "subroutine_declaration_statement ::= docucomment exposure_specifier declaration_modifier_list type declarator param_list SEMICOLON",
 /*  61 */ "subroutine_declaration_statement ::= docucomment exposure_specifier type declarator param_list SEMICOLON",
 /*  62 */ "type ::= type_name",
 /*  63 */ "type ::= type_name asterisk_postfix",
 /*  64 */ "type ::= type_name array_postfix",
 /*  65 */ "type ::= type_qualifier_list type_name",
 /*  66 */ "type ::= type_qualifier_list type_name asterisk_postfix",
 /*  67 */ "type ::= type_qualifier_list type_name array_postfix",
 /*  68 */ "type_name ::= VOID",
 /*  69 */ "type_name ::= VA_LIST",
 /*  70 */ "type_name ::= INTEGER_TYPE_NAME",
 /*  71 */ "type_name ::= FLOAT_TYPE_NAME",
 /*  72 */ "type_name ::= IDENTIFIER",
 /*  73 */ "exposure_specifier ::= PUBLIC",
 /*  74 */ "type_qualifier ::= CONST",
 /*  75 */ "type_qualifier ::= NULLABLE",
 /*  76 */ "type_qualifier ::= INCREMENTED",
 /*  77 */ "type_qualifier ::= DECREMENTED",
 /*  78 */ "type_qualifier_list ::= type_qualifier",
 /*  79 */ "type_qualifier_list ::= type_qualifier_list type_qualifier",
 /*  80 */ "declaration_modifier ::= INERT",
 /*  81 */ "declaration_modifier ::= INLINE",
 /*  82 */ "declaration_modifier ::= ABSTRACT",
 /*  83 */ "declaration_modifier ::= FINAL",
 /*  84 */ "declaration_modifier_list ::= declaration_modifier",
 /*  85 */ "declaration_modifier_list ::= declaration_modifier_list declaration_modifier",
 /*  86 */ "asterisk_postfix ::= ASTERISK",
 /*  87 */ "asterisk_postfix ::= asterisk_postfix ASTERISK",
 /*  88 */ "array_postfix_elem ::= LEFT_SQUARE_BRACKET RIGHT_SQUARE_BRACKET",
 /*  89 */ "array_postfix_elem ::= LEFT_SQUARE_BRACKET INTEGER_LITERAL RIGHT_SQUARE_BRACKET",
 /*  90 */ "array_postfix ::= array_postfix_elem",
 /*  91 */ "array_postfix ::= array_postfix array_postfix_elem",
 /*  92 */ "scalar_constant ::= HEX_LITERAL",
 /*  93 */ "scalar_constant ::= FLOAT_LITERAL",
 /*  94 */ "scalar_constant ::= INTEGER_LITERAL",
 /*  95 */ "scalar_constant ::= STRING_LITERAL",
 /*  96 */ "scalar_constant ::= TRUE",
 /*  97 */ "scalar_constant ::= FALSE",
 /*  98 */ "scalar_constant ::= NULL",
 /*  99 */ "declarator ::= IDENTIFIER",
 /* 100 */ "param_variable ::= type declarator",
 /* 101 */ "param_list ::= LEFT_PAREN RIGHT_PAREN",
 /* 102 */ "param_list ::= LEFT_PAREN param_list_elems RIGHT_PAREN",
 /* 103 */ "param_list ::= LEFT_PAREN param_list_elems COMMA ELLIPSIS RIGHT_PAREN",
 /* 104 */ "param_list_elems ::= param_list_elems COMMA param_variable",
 /* 105 */ "param_list_elems ::= param_list_elems COMMA param_variable EQUALS scalar_constant",
 /* 106 */ "param_list_elems ::= param_variable",
 /* 107 */ "param_list_elems ::= param_variable EQUALS scalar_constant",
 /* 108 */ "qualified_id ::= IDENTIFIER",
 /* 109 */ "qualified_id ::= qualified_id SCOPE_OP IDENTIFIER",
 /* 110 */ "docucomment ::= DOCUCOMMENT",
 /* 111 */ "class_inheritance ::= INHERITS qualified_id",
 /* 112 */ "nickname ::= NICKNAME IDENTIFIER",
 /* 113 */ "cblock ::= CBLOCK_START blob CBLOCK_CLOSE",
 /* 114 */ "cblock ::= CBLOCK_START CBLOCK_CLOSE",
 /* 115 */ "blob ::= BLOB",
 /* 116 */ "blob ::= blob BLOB",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.
*/
static void yyGrowStack(yyParser *p){
  int newSize;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  if( pNew ){
    p->yystack = pNew;
    p->yystksz = newSize;
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows to %d entries!\n",
              yyTracePrompt, p->yystksz);
    }
#endif
  }
}
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to CFCParseHeader and CFCParseHeaderFree.
*/
void *CFCParseHeaderAlloc(void *(*mallocProc)(size_t)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (size_t)sizeof(yyParser) );
  if( pParser ){
    pParser->yyidx = -1;
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyidxMax = 0;
#endif
#if YYSTACKDEPTH<=0
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    yyGrowStack(pParser);
#endif
  }
  return pParser;
}

/* The following function deletes the value associated with a
** symbol.  The symbol can be either a terminal or nonterminal.
** "yymajor" is the symbol code, and "yypminor" is a pointer to
** the value.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  CFCParseHeaderARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are not used
    ** inside the C code.
    */
    case 44: /* result */
    case 46: /* major_block */
    case 52: /* subroutine_declaration_statement */
{
#line 246 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy82)); 
#line 968 "src/CFCParseHeader.c"
}
      break;
    case 45: /* file */
{
#line 247 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy51)); 
#line 975 "src/CFCParseHeader.c"
}
      break;
    case 47: /* parcel_definition */
{
#line 249 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy14)); 
#line 982 "src/CFCParseHeader.c"
}
      break;
    case 48: /* class_declaration */
    case 49: /* class_head */
    case 50: /* class_defs */
{
#line 250 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy141)); 
#line 991 "src/CFCParseHeader.c"
}
      break;
    case 51: /* var_declaration_statement */
    case 54: /* param_variable */
{
#line 253 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy57)); 
#line 999 "src/CFCParseHeader.c"
}
      break;
    case 53: /* type */
{
#line 255 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy41)); 
#line 1006 "src/CFCParseHeader.c"
}
      break;
    case 55: /* param_list */
    case 56: /* param_list_elems */
{
#line 257 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy96)); 
#line 1014 "src/CFCParseHeader.c"
}
      break;
    case 57: /* docucomment */
{
#line 259 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy73)); 
#line 1021 "src/CFCParseHeader.c"
}
      break;
    case 58: /* cblock */
{
#line 260 "src/CFCParseHeader.y"
 CFCBase_decref((CFCBase*)(yypminor->yy117)); 
#line 1028 "src/CFCParseHeader.c"
}
      break;
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
**
** Return the major token number for the symbol popped.
*/
static int yy_pop_parser_stack(yyParser *pParser){
  YYCODETYPE yymajor;
  yyStackEntry *yytos = &pParser->yystack[pParser->yyidx];

  if( pParser->yyidx<0 ) return 0;
#ifndef NDEBUG
  if( yyTraceFILE && pParser->yyidx>=0 ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yymajor = yytos->major;
  yy_destructor(pParser, yymajor, &yytos->minor);
  pParser->yyidx--;
  return yymajor;
}

/* 
** Deallocate and destroy a parser.  Destructors are all called for
** all stack elements before shutting the parser down.
**
** Inputs:
** <ul>
** <li>  A pointer to the parser.  This should be a pointer
**       obtained from CFCParseHeaderAlloc.
** <li>  A pointer to a function used to reclaim memory obtained
**       from malloc.
** </ul>
*/
void CFCParseHeaderFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
  if( pParser==0 ) return;
  while( pParser->yyidx>=0 ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int CFCParseHeaderStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyidxMax;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yystack[pParser->yyidx].stateno;
 
  if( stateno>YY_SHIFT_COUNT
   || (i = yy_shift_ofst[stateno])==YY_SHIFT_USE_DFLT ){
    return yy_default[stateno];
  }
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    if( iLookAhead>0 ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        return yy_find_shift_action(pParser, iFallback);
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
    }
    return yy_default[stateno];
  }else{
    return yy_action[i];
  }
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   CFCParseHeaderARG_FETCH;
   yypParser->yyidx--;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
   CFCParseHeaderARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  YYMINORTYPE *yypMinor         /* Pointer to the minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yyidx++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( yypParser->yyidx>yypParser->yyidxMax ){
    yypParser->yyidxMax = yypParser->yyidx;
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yyidx>=YYSTACKDEPTH ){
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yyidx>=yypParser->yystksz ){
    yyGrowStack(yypParser);
    if( yypParser->yyidx>=yypParser->yystksz ){
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  yytos = &yypParser->yystack[yypParser->yyidx];
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor = *yypMinor;
#ifndef NDEBUG
  if( yyTraceFILE && yypParser->yyidx>0 ){
    int i;
    fprintf(yyTraceFILE,"%sShift %d\n",yyTracePrompt,yyNewState);
    fprintf(yyTraceFILE,"%sStack:",yyTracePrompt);
    for(i=1; i<=yypParser->yyidx; i++)
      fprintf(yyTraceFILE," %s",yyTokenName[yypParser->yystack[i].major]);
    fprintf(yyTraceFILE,"\n");
  }
#endif
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 44, 1 },
  { 44, 1 },
  { 44, 1 },
  { 44, 1 },
  { 44, 1 },
  { 44, 1 },
  { 44, 1 },
  { 44, 1 },
  { 44, 1 },
  { 44, 1 },
  { 45, 2 },
  { 45, 2 },
  { 46, 1 },
  { 46, 1 },
  { 47, 3 },
  { 48, 2 },
  { 49, 7 },
  { 49, 6 },
  { 49, 6 },
  { 49, 5 },
  { 49, 6 },
  { 49, 5 },
  { 49, 5 },
  { 49, 4 },
  { 49, 6 },
  { 49, 5 },
  { 49, 5 },
  { 49, 4 },
  { 49, 5 },
  { 49, 4 },
  { 49, 4 },
  { 49, 3 },
  { 49, 6 },
  { 49, 5 },
  { 49, 5 },
  { 49, 4 },
  { 49, 5 },
  { 49, 4 },
  { 49, 4 },
  { 49, 3 },
  { 49, 5 },
  { 49, 4 },
  { 49, 4 },
  { 49, 3 },
  { 49, 4 },
  { 49, 3 },
  { 49, 3 },
  { 49, 2 },
  { 50, 2 },
  { 50, 2 },
  { 50, 2 },
  { 51, 3 },
  { 51, 4 },
  { 51, 5 },
  { 52, 4 },
  { 52, 5 },
  { 52, 6 },
  { 52, 5 },
  { 52, 5 },
  { 52, 6 },
  { 52, 7 },
  { 52, 6 },
  { 53, 1 },
  { 53, 2 },
  { 53, 2 },
  { 53, 2 },
  { 53, 3 },
  { 53, 3 },
  { 67, 1 },
  { 67, 1 },
  { 67, 1 },
  { 67, 1 },
  { 67, 1 },
  { 62, 1 },
  { 59, 1 },
  { 59, 1 },
  { 59, 1 },
  { 59, 1 },
  { 60, 1 },
  { 60, 2 },
  { 70, 1 },
  { 70, 1 },
  { 70, 1 },
  { 70, 1 },
  { 63, 1 },
  { 63, 2 },
  { 68, 1 },
  { 68, 2 },
  { 71, 2 },
  { 71, 3 },
  { 69, 1 },
  { 69, 2 },
  { 72, 1 },
  { 72, 1 },
  { 72, 1 },
  { 72, 1 },
  { 72, 1 },
  { 72, 1 },
  { 72, 1 },
  { 66, 1 },
  { 54, 2 },
  { 55, 2 },
  { 55, 3 },
  { 55, 5 },
  { 56, 3 },
  { 56, 5 },
  { 56, 1 },
  { 56, 3 },
  { 61, 1 },
  { 61, 3 },
  { 57, 1 },
  { 65, 2 },
  { 64, 2 },
  { 58, 3 },
  { 58, 2 },
  { 73, 1 },
  { 73, 2 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  int yyruleno                 /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  YYMINORTYPE yygotominor;        /* The LHS of the rule reduced */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  CFCParseHeaderARG_FETCH;
  yymsp = &yypParser->yystack[yypParser->yyidx];
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno>=0 
        && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    fprintf(yyTraceFILE, "%sReduce [%s].\n", yyTracePrompt,
      yyRuleName[yyruleno]);
  }
#endif /* NDEBUG */

  /* Silence complaints from purify about yygotominor being uninitialized
  ** in some cases when it is copied into the stack after the following
  ** switch.  yygotominor is uninitialized when a rule reduces that does
  ** not set the value of its left-hand side nonterminal.  Leaving the
  ** value of the nonterminal uninitialized is utterly harmless as long
  ** as the value is never used.  So really the only thing this code
  ** accomplishes is to quieten purify.  
  **
  ** 2007-01-16:  The wireshark project (www.wireshark.org) reports that
  ** without this code, their parser segfaults.  I'm not sure what there
  ** parser is doing to make this happen.  This is the second bug report
  ** from wireshark this week.  Clearly they are stressing Lemon in ways
  ** that it has not been previously stressed...  (SQLite ticket #2172)
  */
  /*memset(&yygotominor, 0, sizeof(yygotominor));*/
  yygotominor = yyzerominor;


  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
      case 0: /* result ::= type */
#line 263 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy41);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy41);
}
#line 1443 "src/CFCParseHeader.c"
        break;
      case 1: /* result ::= param_list */
#line 268 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy96);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy96);
}
#line 1451 "src/CFCParseHeader.c"
        break;
      case 2: /* result ::= param_variable */
      case 6: /* result ::= var_declaration_statement */ yytestcase(yyruleno==6);
#line 273 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy57);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy57);
}
#line 1460 "src/CFCParseHeader.c"
        break;
      case 3: /* result ::= docucomment */
#line 278 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy73);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy73);
}
#line 1468 "src/CFCParseHeader.c"
        break;
      case 4: /* result ::= parcel_definition */
#line 283 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy14);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy14);
}
#line 1476 "src/CFCParseHeader.c"
        break;
      case 5: /* result ::= cblock */
#line 288 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy117);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy117);
}
#line 1484 "src/CFCParseHeader.c"
        break;
      case 7: /* result ::= subroutine_declaration_statement */
#line 298 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy82);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy82);
}
#line 1492 "src/CFCParseHeader.c"
        break;
      case 8: /* result ::= class_declaration */
#line 303 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy141);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy141);
}
#line 1500 "src/CFCParseHeader.c"
        break;
      case 9: /* result ::= file */
#line 308 "src/CFCParseHeader.y"
{
    CFCParser_set_result(state, (CFCBase*)yymsp[0].minor.yy51);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy51);
}
#line 1508 "src/CFCParseHeader.c"
        break;
      case 10: /* file ::= FILE_START parcel_definition */
#line 315 "src/CFCParseHeader.y"
{
    yygotominor.yy51 = CFCFile_new(yymsp[0].minor.yy14, CFCParser_get_file_spec(state));
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy14);
}
#line 1516 "src/CFCParseHeader.c"
        break;
      case 11: /* file ::= file major_block */
#line 320 "src/CFCParseHeader.y"
{
    yygotominor.yy51 = yymsp[-1].minor.yy51;
    CFCFile_add_block(yygotominor.yy51, yymsp[0].minor.yy82);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy82);
}
#line 1525 "src/CFCParseHeader.c"
        break;
      case 12: /* major_block ::= class_declaration */
#line 326 "src/CFCParseHeader.y"
{ yygotominor.yy82 = (CFCBase*)yymsp[0].minor.yy141; }
#line 1530 "src/CFCParseHeader.c"
        break;
      case 13: /* major_block ::= cblock */
#line 327 "src/CFCParseHeader.y"
{ yygotominor.yy82 = (CFCBase*)yymsp[0].minor.yy117; }
#line 1535 "src/CFCParseHeader.c"
        break;
      case 14: /* parcel_definition ::= PARCEL qualified_id SEMICOLON */
#line 330 "src/CFCParseHeader.y"
{
    yygotominor.yy14 = CFCParcel_fetch(yymsp[-1].minor.yy0);
    if (!yygotominor.yy14) {
        /* Allow unregistered parcels to simplify tests. */
        yygotominor.yy14 = CFCParcel_new(yymsp[-1].minor.yy0, NULL, NULL, NULL);
        CFCParcel_register(yygotominor.yy14);
    }
    else {
        CFCBase_incref((CFCBase*)yygotominor.yy14);
    }
    CFCParser_set_parcel(state, yygotominor.yy14);
}
#line 1551 "src/CFCParseHeader.c"
        break;
      case 15: /* class_declaration ::= class_defs RIGHT_CURLY_BRACE */
#line 344 "src/CFCParseHeader.y"
{
    yygotominor.yy141 = yymsp[-1].minor.yy141;
    CFCParser_set_class_name(state, NULL);
    CFCParser_set_class_nickname(state, NULL);
}
#line 1560 "src/CFCParseHeader.c"
        break;
      case 16: /* class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id nickname class_inheritance */
#line 350 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, yymsp[-6].minor.yy73,    yymsp[-5].minor.yy0,    yymsp[-4].minor.yy0,    yymsp[-2].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0   ); }
#line 1565 "src/CFCParseHeader.c"
        break;
      case 17: /* class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id nickname class_inheritance */
#line 351 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, NULL, yymsp[-5].minor.yy0,    yymsp[-4].minor.yy0,    yymsp[-2].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0   ); }
#line 1570 "src/CFCParseHeader.c"
        break;
      case 18: /* class_head ::= docucomment declaration_modifier_list CLASS qualified_id nickname class_inheritance */
#line 352 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, yymsp[-5].minor.yy73,    NULL, yymsp[-4].minor.yy0,    yymsp[-2].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0   ); }
#line 1575 "src/CFCParseHeader.c"
        break;
      case 19: /* class_head ::= declaration_modifier_list CLASS qualified_id nickname class_inheritance */
#line 353 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, NULL, NULL, yymsp[-4].minor.yy0,    yymsp[-2].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0   ); }
#line 1580 "src/CFCParseHeader.c"
        break;
      case 20: /* class_head ::= docucomment exposure_specifier CLASS qualified_id nickname class_inheritance */
#line 354 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, yymsp[-5].minor.yy73,    yymsp[-4].minor.yy0,    NULL, yymsp[-2].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0   ); }
#line 1585 "src/CFCParseHeader.c"
        break;
      case 21: /* class_head ::= exposure_specifier CLASS qualified_id nickname class_inheritance */
#line 355 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, NULL, yymsp[-4].minor.yy0,    NULL, yymsp[-2].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0   ); }
#line 1590 "src/CFCParseHeader.c"
        break;
      case 22: /* class_head ::= docucomment CLASS qualified_id nickname class_inheritance */
#line 356 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, yymsp[-4].minor.yy73,    NULL, NULL, yymsp[-2].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0   ); }
#line 1595 "src/CFCParseHeader.c"
        break;
      case 23: /* class_head ::= CLASS qualified_id nickname class_inheritance */
#line 357 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, NULL, NULL, NULL, yymsp[-2].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0   ); }
#line 1600 "src/CFCParseHeader.c"
        break;
      case 24: /* class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id class_inheritance */
#line 358 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, yymsp[-5].minor.yy73,    yymsp[-4].minor.yy0,    yymsp[-3].minor.yy0,    yymsp[-1].minor.yy0,    NULL, yymsp[0].minor.yy0   ); }
#line 1605 "src/CFCParseHeader.c"
        break;
      case 25: /* class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id class_inheritance */
#line 359 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, NULL, yymsp[-4].minor.yy0,    yymsp[-3].minor.yy0,    yymsp[-1].minor.yy0,    NULL, yymsp[0].minor.yy0   ); }
#line 1610 "src/CFCParseHeader.c"
        break;
      case 26: /* class_head ::= docucomment declaration_modifier_list CLASS qualified_id class_inheritance */
#line 360 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, yymsp[-4].minor.yy73,    NULL, yymsp[-3].minor.yy0,    yymsp[-1].minor.yy0,    NULL, yymsp[0].minor.yy0   ); }
#line 1615 "src/CFCParseHeader.c"
        break;
      case 27: /* class_head ::= declaration_modifier_list CLASS qualified_id class_inheritance */
#line 361 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, NULL, NULL, yymsp[-3].minor.yy0,    yymsp[-1].minor.yy0,    NULL, yymsp[0].minor.yy0   ); }
#line 1620 "src/CFCParseHeader.c"
        break;
      case 28: /* class_head ::= docucomment exposure_specifier CLASS qualified_id class_inheritance */
#line 362 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, yymsp[-4].minor.yy73,    yymsp[-3].minor.yy0,    NULL, yymsp[-1].minor.yy0,    NULL, yymsp[0].minor.yy0   ); }
#line 1625 "src/CFCParseHeader.c"
        break;
      case 29: /* class_head ::= exposure_specifier CLASS qualified_id class_inheritance */
#line 363 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, NULL, yymsp[-3].minor.yy0,    NULL, yymsp[-1].minor.yy0,    NULL, yymsp[0].minor.yy0   ); }
#line 1630 "src/CFCParseHeader.c"
        break;
      case 30: /* class_head ::= docucomment CLASS qualified_id class_inheritance */
#line 364 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, yymsp[-3].minor.yy73,    NULL, NULL, yymsp[-1].minor.yy0,    NULL, yymsp[0].minor.yy0   ); }
#line 1635 "src/CFCParseHeader.c"
        break;
      case 31: /* class_head ::= CLASS qualified_id class_inheritance */
#line 365 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, NULL, NULL, NULL, yymsp[-1].minor.yy0,    NULL, yymsp[0].minor.yy0   ); }
#line 1640 "src/CFCParseHeader.c"
        break;
      case 32: /* class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id nickname */
#line 366 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, yymsp[-5].minor.yy73,    yymsp[-4].minor.yy0,    yymsp[-3].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0,    NULL ); }
#line 1645 "src/CFCParseHeader.c"
        break;
      case 33: /* class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id nickname */
#line 367 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, NULL, yymsp[-4].minor.yy0,    yymsp[-3].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0,    NULL ); }
#line 1650 "src/CFCParseHeader.c"
        break;
      case 34: /* class_head ::= docucomment declaration_modifier_list CLASS qualified_id nickname */
#line 368 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, yymsp[-4].minor.yy73,    NULL, yymsp[-3].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0,    NULL ); }
#line 1655 "src/CFCParseHeader.c"
        break;
      case 35: /* class_head ::= declaration_modifier_list CLASS qualified_id nickname */
#line 369 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, NULL, NULL, yymsp[-3].minor.yy0,    yymsp[-1].minor.yy0,    yymsp[0].minor.yy0,    NULL ); }
#line 1660 "src/CFCParseHeader.c"
        break;
      case 36: /* class_head ::= docucomment exposure_specifier CLASS qualified_id nickname */
#line 370 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, yymsp[-4].minor.yy73,    yymsp[-3].minor.yy0,    NULL, yymsp[-1].minor.yy0,    yymsp[0].minor.yy0,    NULL ); }
#line 1665 "src/CFCParseHeader.c"
        break;
      case 37: /* class_head ::= exposure_specifier CLASS qualified_id nickname */
#line 371 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, NULL, yymsp[-3].minor.yy0,    NULL, yymsp[-1].minor.yy0,    yymsp[0].minor.yy0,    NULL ); }
#line 1670 "src/CFCParseHeader.c"
        break;
      case 38: /* class_head ::= docucomment CLASS qualified_id nickname */
#line 372 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, yymsp[-3].minor.yy73,    NULL, NULL, yymsp[-1].minor.yy0,    yymsp[0].minor.yy0,    NULL ); }
#line 1675 "src/CFCParseHeader.c"
        break;
      case 39: /* class_head ::= CLASS qualified_id nickname */
#line 373 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, NULL, NULL, NULL, yymsp[-1].minor.yy0,    yymsp[0].minor.yy0,    NULL ); }
#line 1680 "src/CFCParseHeader.c"
        break;
      case 40: /* class_head ::= docucomment exposure_specifier declaration_modifier_list CLASS qualified_id */
#line 374 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, yymsp[-4].minor.yy73,    yymsp[-3].minor.yy0,    yymsp[-2].minor.yy0,    yymsp[0].minor.yy0,    NULL, NULL ); }
#line 1685 "src/CFCParseHeader.c"
        break;
      case 41: /* class_head ::= exposure_specifier declaration_modifier_list CLASS qualified_id */
#line 375 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, NULL, yymsp[-3].minor.yy0,    yymsp[-2].minor.yy0,    yymsp[0].minor.yy0,    NULL, NULL ); }
#line 1690 "src/CFCParseHeader.c"
        break;
      case 42: /* class_head ::= docucomment declaration_modifier_list CLASS qualified_id */
#line 376 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, yymsp[-3].minor.yy73,    NULL, yymsp[-2].minor.yy0,    yymsp[0].minor.yy0,    NULL, NULL ); }
#line 1695 "src/CFCParseHeader.c"
        break;
      case 43: /* class_head ::= declaration_modifier_list CLASS qualified_id */
#line 377 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, NULL, NULL, yymsp[-2].minor.yy0,    yymsp[0].minor.yy0,    NULL, NULL ); }
#line 1700 "src/CFCParseHeader.c"
        break;
      case 44: /* class_head ::= docucomment exposure_specifier CLASS qualified_id */
#line 378 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, yymsp[-3].minor.yy73,    yymsp[-2].minor.yy0,    NULL, yymsp[0].minor.yy0,    NULL, NULL ); }
#line 1705 "src/CFCParseHeader.c"
        break;
      case 45: /* class_head ::= exposure_specifier CLASS qualified_id */
#line 379 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, NULL, yymsp[-2].minor.yy0,    NULL, yymsp[0].minor.yy0,    NULL, NULL ); }
#line 1710 "src/CFCParseHeader.c"
        break;
      case 46: /* class_head ::= docucomment CLASS qualified_id */
#line 380 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, yymsp[-2].minor.yy73,    NULL, NULL, yymsp[0].minor.yy0,    NULL, NULL ); }
#line 1715 "src/CFCParseHeader.c"
        break;
      case 47: /* class_head ::= CLASS qualified_id */
#line 381 "src/CFCParseHeader.y"
{ yygotominor.yy141 = S_start_class(state, NULL, NULL, NULL, yymsp[0].minor.yy0,    NULL, NULL ); }
#line 1720 "src/CFCParseHeader.c"
        break;
      case 48: /* class_defs ::= class_head LEFT_CURLY_BRACE */
#line 384 "src/CFCParseHeader.y"
{
    yygotominor.yy141 = yymsp[-1].minor.yy141;
}
#line 1727 "src/CFCParseHeader.c"
        break;
      case 49: /* class_defs ::= class_defs var_declaration_statement */
#line 388 "src/CFCParseHeader.y"
{
    yygotominor.yy141 = yymsp[-1].minor.yy141;
    if (CFCVariable_inert(yymsp[0].minor.yy57)) {
        CFCClass_add_inert_var(yygotominor.yy141, yymsp[0].minor.yy57);
    }
    else {
        CFCClass_add_member_var(yygotominor.yy141, yymsp[0].minor.yy57);
    }
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy57);
}
#line 1741 "src/CFCParseHeader.c"
        break;
      case 50: /* class_defs ::= class_defs subroutine_declaration_statement */
#line 399 "src/CFCParseHeader.y"
{
    yygotominor.yy141 = yymsp[-1].minor.yy141;
    if (strcmp(CFCBase_get_cfc_class(yymsp[0].minor.yy82), "Clownfish::CFC::Model::Function") == 0) {
        CFCClass_add_function(yygotominor.yy141, (CFCFunction*)yymsp[0].minor.yy82);
    }
    else {
        CFCClass_add_method(yygotominor.yy141, (CFCMethod*)yymsp[0].minor.yy82);
    }
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy82);
}
#line 1755 "src/CFCParseHeader.c"
        break;
      case 51: /* var_declaration_statement ::= type declarator SEMICOLON */
#line 412 "src/CFCParseHeader.y"
{
    yygotominor.yy57 = S_new_var(state, CFCParser_dupe(state, "private"), NULL, yymsp[-2].minor.yy41, yymsp[-1].minor.yy0);
}
#line 1762 "src/CFCParseHeader.c"
        break;
      case 52: /* var_declaration_statement ::= declaration_modifier_list type declarator SEMICOLON */
#line 418 "src/CFCParseHeader.y"
{
    yygotominor.yy57 = S_new_var(state, CFCParser_dupe(state, "parcel"), yymsp[-3].minor.yy0, yymsp[-2].minor.yy41, yymsp[-1].minor.yy0);
}
#line 1769 "src/CFCParseHeader.c"
        break;
      case 53: /* var_declaration_statement ::= exposure_specifier declaration_modifier_list type declarator SEMICOLON */
#line 425 "src/CFCParseHeader.y"
{
    yygotominor.yy57 = S_new_var(state, yymsp[-4].minor.yy0, yymsp[-3].minor.yy0, yymsp[-2].minor.yy41, yymsp[-1].minor.yy0);
}
#line 1776 "src/CFCParseHeader.c"
        break;
      case 54: /* subroutine_declaration_statement ::= type declarator param_list SEMICOLON */
#line 431 "src/CFCParseHeader.y"
{
    yygotominor.yy82 = S_new_sub(state, NULL, NULL, NULL, yymsp[-3].minor.yy41, yymsp[-2].minor.yy0, yymsp[-1].minor.yy96);
}
#line 1783 "src/CFCParseHeader.c"
        break;
      case 55: /* subroutine_declaration_statement ::= declaration_modifier_list type declarator param_list SEMICOLON */
#line 437 "src/CFCParseHeader.y"
{
    yygotominor.yy82 = S_new_sub(state, NULL, NULL, yymsp[-4].minor.yy0, yymsp[-3].minor.yy41, yymsp[-2].minor.yy0, yymsp[-1].minor.yy96);
}
#line 1790 "src/CFCParseHeader.c"
        break;
      case 56: /* subroutine_declaration_statement ::= exposure_specifier declaration_modifier_list type declarator param_list SEMICOLON */
#line 444 "src/CFCParseHeader.y"
{
    yygotominor.yy82 = S_new_sub(state, NULL, yymsp[-5].minor.yy0, yymsp[-4].minor.yy0, yymsp[-3].minor.yy41, yymsp[-2].minor.yy0, yymsp[-1].minor.yy96);
}
#line 1797 "src/CFCParseHeader.c"
        break;
      case 57: /* subroutine_declaration_statement ::= exposure_specifier type declarator param_list SEMICOLON */
#line 450 "src/CFCParseHeader.y"
{
    yygotominor.yy82 = S_new_sub(state, NULL, yymsp[-4].minor.yy0, NULL, yymsp[-3].minor.yy41, yymsp[-2].minor.yy0, yymsp[-1].minor.yy96);
}
#line 1804 "src/CFCParseHeader.c"
        break;
      case 58: /* subroutine_declaration_statement ::= docucomment type declarator param_list SEMICOLON */
#line 456 "src/CFCParseHeader.y"
{
    yygotominor.yy82 = S_new_sub(state, yymsp[-4].minor.yy73, NULL, NULL, yymsp[-3].minor.yy41, yymsp[-2].minor.yy0, yymsp[-1].minor.yy96);
}
#line 1811 "src/CFCParseHeader.c"
        break;
      case 59: /* subroutine_declaration_statement ::= docucomment declaration_modifier_list type declarator param_list SEMICOLON */
#line 463 "src/CFCParseHeader.y"
{
    yygotominor.yy82 = S_new_sub(state, yymsp[-5].minor.yy73, NULL, yymsp[-4].minor.yy0, yymsp[-3].minor.yy41, yymsp[-2].minor.yy0, yymsp[-1].minor.yy96);
}
#line 1818 "src/CFCParseHeader.c"
        break;
      case 60: /* subroutine_declaration_statement ::= docucomment exposure_specifier declaration_modifier_list type declarator param_list SEMICOLON */
#line 471 "src/CFCParseHeader.y"
{
    yygotominor.yy82 = S_new_sub(state, yymsp[-6].minor.yy73, yymsp[-5].minor.yy0, yymsp[-4].minor.yy0, yymsp[-3].minor.yy41, yymsp[-2].minor.yy0, yymsp[-1].minor.yy96);
}
#line 1825 "src/CFCParseHeader.c"
        break;
      case 61: /* subroutine_declaration_statement ::= docucomment exposure_specifier type declarator param_list SEMICOLON */
#line 478 "src/CFCParseHeader.y"
{
    yygotominor.yy82 = S_new_sub(state, yymsp[-5].minor.yy73, yymsp[-4].minor.yy0, NULL, yymsp[-3].minor.yy41, yymsp[-2].minor.yy0, yymsp[-1].minor.yy96);
}
#line 1832 "src/CFCParseHeader.c"
        break;
      case 62: /* type ::= type_name */
#line 483 "src/CFCParseHeader.y"
{
    yygotominor.yy41 = S_new_type(state, 0, yymsp[0].minor.yy0, NULL, NULL);
}
#line 1839 "src/CFCParseHeader.c"
        break;
      case 63: /* type ::= type_name asterisk_postfix */
#line 487 "src/CFCParseHeader.y"
{
    yygotominor.yy41 = S_new_type(state, 0, yymsp[-1].minor.yy0, yymsp[0].minor.yy0, NULL);
}
#line 1846 "src/CFCParseHeader.c"
        break;
      case 64: /* type ::= type_name array_postfix */
#line 491 "src/CFCParseHeader.y"
{
    yygotominor.yy41 = S_new_type(state, 0, yymsp[-1].minor.yy0, NULL, yymsp[0].minor.yy0);
}
#line 1853 "src/CFCParseHeader.c"
        break;
      case 65: /* type ::= type_qualifier_list type_name */
#line 495 "src/CFCParseHeader.y"
{
    yygotominor.yy41 = S_new_type(state, yymsp[-1].minor.yy8, yymsp[0].minor.yy0, NULL, NULL);
}
#line 1860 "src/CFCParseHeader.c"
        break;
      case 66: /* type ::= type_qualifier_list type_name asterisk_postfix */
#line 499 "src/CFCParseHeader.y"
{
    yygotominor.yy41 = S_new_type(state, yymsp[-2].minor.yy8, yymsp[-1].minor.yy0, yymsp[0].minor.yy0, NULL);
}
#line 1867 "src/CFCParseHeader.c"
        break;
      case 67: /* type ::= type_qualifier_list type_name array_postfix */
#line 503 "src/CFCParseHeader.y"
{
    yygotominor.yy41 = S_new_type(state, yymsp[-2].minor.yy8, yymsp[-1].minor.yy0, NULL, yymsp[0].minor.yy0);
}
#line 1874 "src/CFCParseHeader.c"
        break;
      case 68: /* type_name ::= VOID */
      case 69: /* type_name ::= VA_LIST */ yytestcase(yyruleno==69);
      case 70: /* type_name ::= INTEGER_TYPE_NAME */ yytestcase(yyruleno==70);
      case 71: /* type_name ::= FLOAT_TYPE_NAME */ yytestcase(yyruleno==71);
      case 72: /* type_name ::= IDENTIFIER */ yytestcase(yyruleno==72);
      case 73: /* exposure_specifier ::= PUBLIC */ yytestcase(yyruleno==73);
      case 80: /* declaration_modifier ::= INERT */ yytestcase(yyruleno==80);
      case 81: /* declaration_modifier ::= INLINE */ yytestcase(yyruleno==81);
      case 82: /* declaration_modifier ::= ABSTRACT */ yytestcase(yyruleno==82);
      case 83: /* declaration_modifier ::= FINAL */ yytestcase(yyruleno==83);
      case 84: /* declaration_modifier_list ::= declaration_modifier */ yytestcase(yyruleno==84);
      case 86: /* asterisk_postfix ::= ASTERISK */ yytestcase(yyruleno==86);
      case 90: /* array_postfix ::= array_postfix_elem */ yytestcase(yyruleno==90);
      case 92: /* scalar_constant ::= HEX_LITERAL */ yytestcase(yyruleno==92);
      case 93: /* scalar_constant ::= FLOAT_LITERAL */ yytestcase(yyruleno==93);
      case 94: /* scalar_constant ::= INTEGER_LITERAL */ yytestcase(yyruleno==94);
      case 95: /* scalar_constant ::= STRING_LITERAL */ yytestcase(yyruleno==95);
      case 96: /* scalar_constant ::= TRUE */ yytestcase(yyruleno==96);
      case 97: /* scalar_constant ::= FALSE */ yytestcase(yyruleno==97);
      case 98: /* scalar_constant ::= NULL */ yytestcase(yyruleno==98);
      case 108: /* qualified_id ::= IDENTIFIER */ yytestcase(yyruleno==108);
      case 111: /* class_inheritance ::= INHERITS qualified_id */ yytestcase(yyruleno==111);
      case 112: /* nickname ::= NICKNAME IDENTIFIER */ yytestcase(yyruleno==112);
      case 115: /* blob ::= BLOB */ yytestcase(yyruleno==115);
#line 507 "src/CFCParseHeader.y"
{ yygotominor.yy0 = yymsp[0].minor.yy0; }
#line 1902 "src/CFCParseHeader.c"
        break;
      case 74: /* type_qualifier ::= CONST */
#line 515 "src/CFCParseHeader.y"
{ yygotominor.yy8 = CFCTYPE_CONST; }
#line 1907 "src/CFCParseHeader.c"
        break;
      case 75: /* type_qualifier ::= NULLABLE */
#line 516 "src/CFCParseHeader.y"
{ yygotominor.yy8 = CFCTYPE_NULLABLE; }
#line 1912 "src/CFCParseHeader.c"
        break;
      case 76: /* type_qualifier ::= INCREMENTED */
#line 517 "src/CFCParseHeader.y"
{ yygotominor.yy8 = CFCTYPE_INCREMENTED; }
#line 1917 "src/CFCParseHeader.c"
        break;
      case 77: /* type_qualifier ::= DECREMENTED */
#line 518 "src/CFCParseHeader.y"
{ yygotominor.yy8 = CFCTYPE_DECREMENTED; }
#line 1922 "src/CFCParseHeader.c"
        break;
      case 78: /* type_qualifier_list ::= type_qualifier */
#line 521 "src/CFCParseHeader.y"
{
    yygotominor.yy8 = yymsp[0].minor.yy8;
}
#line 1929 "src/CFCParseHeader.c"
        break;
      case 79: /* type_qualifier_list ::= type_qualifier_list type_qualifier */
#line 525 "src/CFCParseHeader.y"
{
    yygotominor.yy8 = yymsp[-1].minor.yy8;
    yygotominor.yy8 |= yymsp[0].minor.yy8;
}
#line 1937 "src/CFCParseHeader.c"
        break;
      case 85: /* declaration_modifier_list ::= declaration_modifier_list declaration_modifier */
#line 537 "src/CFCParseHeader.y"
{
    size_t size = strlen(yymsp[-1].minor.yy0) + strlen(yymsp[0].minor.yy0) + 2;
    yygotominor.yy0 = (char*)CFCParser_allocate(state, size);
    sprintf(yygotominor.yy0, "%s %s", yymsp[-1].minor.yy0, yymsp[0].minor.yy0);
}
#line 1946 "src/CFCParseHeader.c"
        break;
      case 87: /* asterisk_postfix ::= asterisk_postfix ASTERISK */
#line 545 "src/CFCParseHeader.y"
{
    size_t size = strlen(yymsp[-1].minor.yy0) + 2;
    yygotominor.yy0 = (char*)CFCParser_allocate(state, size);
    sprintf(yygotominor.yy0, "%s*", yymsp[-1].minor.yy0);
}
#line 1955 "src/CFCParseHeader.c"
        break;
      case 88: /* array_postfix_elem ::= LEFT_SQUARE_BRACKET RIGHT_SQUARE_BRACKET */
#line 552 "src/CFCParseHeader.y"
{
    yygotominor.yy0 = CFCParser_dupe(state, "[]");
}
#line 1962 "src/CFCParseHeader.c"
        break;
      case 89: /* array_postfix_elem ::= LEFT_SQUARE_BRACKET INTEGER_LITERAL RIGHT_SQUARE_BRACKET */
#line 556 "src/CFCParseHeader.y"
{
    size_t size = strlen(yymsp[-1].minor.yy0) + 3;
    yygotominor.yy0 = (char*)CFCParser_allocate(state, size);
    sprintf(yygotominor.yy0, "[%s]", yymsp[-1].minor.yy0);
}
#line 1971 "src/CFCParseHeader.c"
        break;
      case 91: /* array_postfix ::= array_postfix array_postfix_elem */
      case 116: /* blob ::= blob BLOB */ yytestcase(yyruleno==116);
#line 564 "src/CFCParseHeader.y"
{
    size_t size = strlen(yymsp[-1].minor.yy0) + strlen(yymsp[0].minor.yy0) + 1;
    yygotominor.yy0 = (char*)CFCParser_allocate(state, size);
    sprintf(yygotominor.yy0, "%s%s", yymsp[-1].minor.yy0, yymsp[0].minor.yy0);
}
#line 1981 "src/CFCParseHeader.c"
        break;
      case 99: /* declarator ::= IDENTIFIER */
#line 579 "src/CFCParseHeader.y"
{
    yygotominor.yy0 = yymsp[0].minor.yy0;
}
#line 1988 "src/CFCParseHeader.c"
        break;
      case 100: /* param_variable ::= type declarator */
#line 584 "src/CFCParseHeader.y"
{
    yygotominor.yy57 = S_new_var(state, NULL, NULL, yymsp[-1].minor.yy41, yymsp[0].minor.yy0);
}
#line 1995 "src/CFCParseHeader.c"
        break;
      case 101: /* param_list ::= LEFT_PAREN RIGHT_PAREN */
#line 589 "src/CFCParseHeader.y"
{
    yygotominor.yy96 = CFCParamList_new(false);
}
#line 2002 "src/CFCParseHeader.c"
        break;
      case 102: /* param_list ::= LEFT_PAREN param_list_elems RIGHT_PAREN */
#line 593 "src/CFCParseHeader.y"
{
    yygotominor.yy96 = yymsp[-1].minor.yy96;
}
#line 2009 "src/CFCParseHeader.c"
        break;
      case 103: /* param_list ::= LEFT_PAREN param_list_elems COMMA ELLIPSIS RIGHT_PAREN */
#line 597 "src/CFCParseHeader.y"
{
    yygotominor.yy96 = yymsp[-3].minor.yy96;
    CFCParamList_set_variadic(yygotominor.yy96, true);
}
#line 2017 "src/CFCParseHeader.c"
        break;
      case 104: /* param_list_elems ::= param_list_elems COMMA param_variable */
#line 602 "src/CFCParseHeader.y"
{
    yygotominor.yy96 = yymsp[-2].minor.yy96;
    CFCParamList_add_param(yygotominor.yy96, yymsp[0].minor.yy57, NULL);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy57);
}
#line 2026 "src/CFCParseHeader.c"
        break;
      case 105: /* param_list_elems ::= param_list_elems COMMA param_variable EQUALS scalar_constant */
#line 608 "src/CFCParseHeader.y"
{
    yygotominor.yy96 = yymsp[-4].minor.yy96;
    CFCParamList_add_param(yygotominor.yy96, yymsp[-2].minor.yy57, yymsp[0].minor.yy0);
    CFCBase_decref((CFCBase*)yymsp[-2].minor.yy57);
}
#line 2035 "src/CFCParseHeader.c"
        break;
      case 106: /* param_list_elems ::= param_variable */
#line 614 "src/CFCParseHeader.y"
{
    yygotominor.yy96 = CFCParamList_new(false);
    CFCParamList_add_param(yygotominor.yy96, yymsp[0].minor.yy57, NULL);
    CFCBase_decref((CFCBase*)yymsp[0].minor.yy57);
}
#line 2044 "src/CFCParseHeader.c"
        break;
      case 107: /* param_list_elems ::= param_variable EQUALS scalar_constant */
#line 620 "src/CFCParseHeader.y"
{
    yygotominor.yy96 = CFCParamList_new(false);
    CFCParamList_add_param(yygotominor.yy96, yymsp[-2].minor.yy57, yymsp[0].minor.yy0);
    CFCBase_decref((CFCBase*)yymsp[-2].minor.yy57);
}
#line 2053 "src/CFCParseHeader.c"
        break;
      case 109: /* qualified_id ::= qualified_id SCOPE_OP IDENTIFIER */
#line 628 "src/CFCParseHeader.y"
{
    size_t size = strlen(yymsp[-2].minor.yy0) + strlen(yymsp[0].minor.yy0) + 3;
    yygotominor.yy0 = (char*)CFCParser_allocate(state, size);
    sprintf(yygotominor.yy0, "%s::%s", yymsp[-2].minor.yy0, yymsp[0].minor.yy0);
}
#line 2062 "src/CFCParseHeader.c"
        break;
      case 110: /* docucomment ::= DOCUCOMMENT */
#line 634 "src/CFCParseHeader.y"
{ yygotominor.yy73 = CFCDocuComment_parse(yymsp[0].minor.yy0); }
#line 2067 "src/CFCParseHeader.c"
        break;
      case 113: /* cblock ::= CBLOCK_START blob CBLOCK_CLOSE */
#line 637 "src/CFCParseHeader.y"
{ yygotominor.yy117 = CFCCBlock_new(yymsp[-1].minor.yy0); }
#line 2072 "src/CFCParseHeader.c"
        break;
      case 114: /* cblock ::= CBLOCK_START CBLOCK_CLOSE */
#line 638 "src/CFCParseHeader.y"
{ yygotominor.yy117 = CFCCBlock_new(""); }
#line 2077 "src/CFCParseHeader.c"
        break;
      default:
        break;
  };
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yypParser->yyidx -= yysize;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact < YYNSTATE ){
#ifdef NDEBUG
    /* If we are not debugging and the reduce action popped at least
    ** one element off the stack, then we can push the new element back
    ** onto the stack here, and skip the stack overflow test in yy_shift().
    ** That gives a significant speed improvement. */
    if( yysize ){
      yypParser->yyidx++;
      yymsp -= yysize-1;
      yymsp->stateno = (YYACTIONTYPE)yyact;
      yymsp->major = (YYCODETYPE)yygoto;
      yymsp->minor = yygotominor;
    }else
#endif
    {
      yy_shift(yypParser,yyact,yygoto,&yygotominor);
    }
  }else{
    assert( yyact == YYNSTATE + YYNRULE + 1 );
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  CFCParseHeaderARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
  CFCParseHeaderARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  YYMINORTYPE yyminor            /* The minor type of the error token */
){
  CFCParseHeaderARG_FETCH;
#define TOKEN (yyminor.yy0)
#line 221 "src/CFCParseHeader.y"

    (void)yymajor;
    (void)yyminor;
    CFCParser_set_errors(state, true);
    CFCParser_set_lineno(state, yyget_lineno());
#line 2145 "src/CFCParseHeader.c"
  CFCParseHeaderARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  CFCParseHeaderARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
  CFCParseHeaderARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "CFCParseHeaderAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void CFCParseHeader(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  CFCParseHeaderTOKENTYPE yyminor       /* The value for the token */
  CFCParseHeaderARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  int yyact;            /* The parser action. */
  int yyendofinput;     /* True if we are at the end of input */
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  /* (re)initialize the parser, if necessary */
  yypParser = (yyParser*)yyp;
  if( yypParser->yyidx<0 ){
#if YYSTACKDEPTH<=0
    if( yypParser->yystksz <=0 ){
      yyStackOverflow(yypParser);
      return;
    }
#endif
    yypParser->yyidx = 0;
    yypParser->yyerrcnt = -1;
    yypParser->yystack[0].stateno = 0;
    yypParser->yystack[0].major = 0;
  }
  yyminorunion.yy0 = yyminor;
  yyendofinput = (yymajor==0);
  CFCParseHeaderARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput %s\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact<YYNSTATE ){
      assert( !yyendofinput );  /* Impossible to shift the $ token */
      yy_shift(yypParser,yyact,yymajor,&yyminorunion);
      yypParser->yyerrcnt--;
      yymajor = YYNOCODE;
    }else if( yyact < YYNSTATE + YYNRULE ){
      yy_reduce(yypParser,yyact-YYNSTATE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yymx = yypParser->yystack[yypParser->yyidx].major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor,&yyminorunion);
        yymajor = YYNOCODE;
      }else{
         while(
          yypParser->yyidx >= 0 &&
          yymx != YYERRORSYMBOL &&
          (yyact = yy_find_reduce_action(
                        yypParser->yystack[yypParser->yyidx].stateno,
                        YYERRORSYMBOL)) >= YYNSTATE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yyidx < 0 || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          YYMINORTYPE u2;
          u2.YYERRSYMDT = 0;
          yy_shift(yypParser,yyact,YYERRORSYMBOL,&u2);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor,yyminorunion);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yyidx>=0 );
  return;
}
